@@ -85,8 +85,7 @@ class ClientTest(unittest.TestCase):
 		for obj in objs:
 			self.assertIs(type(obj.get()), int)
 	def test8(self):
-		log = logging.getLogger("test8.Client")
-		fec = Client("a344613fe3d9ea517ffa0e89e645cdbc", "417e9e027bcd7efb89d250a7cbf701b4", log=log, compression=False)
+		fec = Client("a344613fe3d9ea517ffa0e89e645cdbc", "417e9e027bcd7efb89d250a7cbf701b4", log=logging.getLogger("test8.Client"), compression=False)
 		obj = fec.request("sleepWell", [1])
 		if obj.isSuccess():
 			self.assertEqual(obj.get(), True)
